@@ -114,10 +114,8 @@ process_grid <- function(gt, bbx, proj, sasp) {
 				
 				lns <- st_sf(ID=c("x", "y")[lnsSel], geometry = st_sfc(lnsList[lnsSel], crs = grid.projection))
 				
-				#lns <- SpatialLinesDataFrame(SpatialLines(lnsList[lnsSel], proj4string = get_proj4(grid.projection, output="CRS")), data.frame(ID=c("x", "y")[lnsSel]), match.ID=FALSE)
-				
 				# project it to current projection
-				lns_proj <- tmaptools::set_projection(lns, projection = proj)
+				lns_proj <- sf::st_transform(lns, crs = proj)
 
 				
 				# extract and normalize coordinates
@@ -167,7 +165,6 @@ process_grid <- function(gt, bbx, proj, sasp) {
 			# normalize coordinates
 			grid.co.x <- (grid.x-bbx[1]) / (bbx[3] - bbx[1])
 			grid.co.y <- (grid.y-bbx[2]) / (bbx[4] - bbx[2])
-			
 		}
 		
 		## format grid labels
@@ -228,7 +225,7 @@ plot_grid_labels_x <- function(gt, scale) {
 
 	just <- ifelse(gt$grid.labels.rot[1] == 90, "right", ifelse(gt$grid.labels.rot[1] == 270, "left", ifelse(gt$grid.labels.rot[1] == 180, "bottom", "top")))
 	
-	if (gt$grid.ticks) {
+	if (gt$grid.ticks[1]) {
 		ticks <- polylineGrob(x=rep(cogridx, each = 2), y = rep(c(1-spacerX*.5-marginX,1), length(cogridx)), id = rep(1:length(cogridx), each = 2), gp=gpar(col=gt$grid.col, lwd=gt$grid.lwd))	
 	} else {
 		ticks <- NULL
@@ -260,7 +257,7 @@ plot_grid_labels_y <- function(gt, scale) {
 	
 	just <- ifelse(gt$grid.labels.rot[2] == 90, "bottom", ifelse(gt$grid.labels.rot[2] == 270, "top", ifelse(gt$grid.labels.rot[2] == 180, "left", "right")))
 	
-	if (gt$grid.ticks) {
+	if (gt$grid.ticks[2]) {
 		ticks <- polylineGrob(x = rep(c(1-spacerY*.5-marginY, 1), length(cogridy)), y = rep(cogridy, each = 2), id = rep(1:length(cogridy), each = 2), gp=gpar(col=gt$grid.col, lwd=gt$grid.lwd))
 	} else {
 		ticks <- NULL
@@ -274,7 +271,7 @@ plot_grid_labels_y <- function(gt, scale) {
 plot_grid <- function(gt, scale, add.labels) {
 	
 	
-	if (gt$grid.labels.inside.frame && gt$grid.ticks) warning("Grid ticks are not supported when labels.inside.frame = TRUE", call. = FALSE)
+	if (gt$grid.labels.inside.frame && any(gt$grid.ticks)) warning("Grid ticks are not supported when labels.inside.frame = TRUE", call. = FALSE)
 
 	
 	## might be confusing: gridx are grid lines for the x-axis, so they are vertical
@@ -290,39 +287,45 @@ plot_grid <- function(gt, scale, add.labels) {
 	sely <- (length(cogridy) > 0)
 	
 	# find margins due to grid labels
-	if (add.labels) {
-		if (!is.na(gt$frame)) {
-			if (gt$frame.double.line) {
-				fw <- 6 * convertWidth(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
-				fh <- 6 * convertHeight(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
-			} else {
-				fw <- convertWidth(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
-				fh <- convertHeight(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
-			}
+	if (!is.na(gt$frame)) {
+		if (gt$frame.double.line) {
+			fw <- 6 * convertWidth(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
+			fh <- 6 * convertHeight(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
 		} else {
-			fw <- 0
-			fh <- 0
+			fw <- convertWidth(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
+			fh <- convertHeight(unit(1, "points"), unitTo = "npc", valueOnly = TRUE) * gt$frame.lwd
 		}
-		
+	} else {
+		fw <- 0
+		fh <- 0
+	}
+	
+	
+	if (add.labels[1]) {
 		if (gt$grid.labels.rot[1] %in% c(0, 180)) {
 			labelsXw <- if (selx) max(text_height_npc(labelsx))  * cex + fh else 0
 		} else {
 			labelsXw <- if (selx) max(text_width_npc(labelsx, space=FALSE, to_height = TRUE))  * cex + fh else 0
 		}
+		spacerX <- convertHeight(unit(.5, "lines"), unitTo="npc", valueOnly=TRUE) * cex
+		marginX <- convertWidth(unit(gt$grid.labels.margin.x, "lines"), unitTo="npc", valueOnly=TRUE) * cex
+	} else {
+		labelsXw <- spacerX <- marginX <- 0
+	}
 		
+		
+	if (add.labels[2]) {
 		if (gt$grid.labels.rot[2] %in% c(0, 180)) {
 			labelsYw <- if (sely) max(text_width_npc(labelsy, space=FALSE))  * cex + fw else 0
 		} else {
 			labelsYw <- if (sely) max(text_height_npc(labelsy, to_width = TRUE))  * cex + fw else 0
 		}
-		
 		spacerY <- convertWidth(unit(.5, "lines"), unitTo="npc", valueOnly=TRUE) * cex
-		spacerX <- convertHeight(unit(.5, "lines"), unitTo="npc", valueOnly=TRUE) * cex
 		marginY <- convertWidth(unit(gt$grid.labels.margin.y, "lines"), unitTo="npc", valueOnly=TRUE) * cex
-		marginX <- convertWidth(unit(gt$grid.labels.margin.x, "lines"), unitTo="npc", valueOnly=TRUE) * cex
 	} else {
-		labelsXw <- labelsYw <- spacerX <- spacerY <- marginY <- marginX <- 0
+		labelsYw <- spacerY <- marginY <- 0
 	}	
+	
 	# find coordinates for projected grid labels
 	if (!is.na(gt$grid.projection)) {
 		glabelsx <- if (selx) get_gridline_labels(lco=gt$grid.co.x.lns[gt$grid.sel.x], xax = labelsXw + spacerX+marginX) else numeric(0)
@@ -400,7 +403,7 @@ plot_grid <- function(gt, scale, add.labels) {
 			grobGridX <- polylineGrob(x=cogridxlns$x, y=cogridxlns$y, id=cogridxlns$ID, gp=gpar(col=gt$grid.col, lwd=gt$grid.lwd))
 		}
 		
-		grobGridTextX <- if (add.labels && any(selx2)) {
+		grobGridTextX <- if (add.labels[1] && any(selx2)) {
 			just <- ifelse(gt$grid.labels.rot[1] == 90, "right", ifelse(gt$grid.labels.rot[1] == 270, "left", ifelse(gt$grid.labels.rot[1] == 180, "bottom", "top")))
 
 			textGrob(labelsx, y=labelsXw+spacerX*.5+marginX, x=cogridx3, just=just, rot=gt$grid.labels.rot[1], gp=gpar(col=gt$grid.labels.col, cex=cex, fontface=gt$fontface, fontfamily=gt$fontfamily))
@@ -426,7 +429,7 @@ plot_grid <- function(gt, scale, add.labels) {
 			grobGridY <- polylineGrob(x=cogridylns$x, y=cogridylns$y, id=cogridylns$ID, gp=gpar(col=gt$grid.col, lwd=gt$grid.lwd))
 		}
 		
-		grobGridTextY <- if (add.labels && any(sely2)) {
+		grobGridTextY <- if (add.labels[2] && any(sely2)) {
 			just <- ifelse(gt$grid.labels.rot[2] == 90, "bottom", ifelse(gt$grid.labels.rot[2] == 270, "top", ifelse(gt$grid.labels.rot[2] == 180, "left", "right")))
 
 			textGrob(labelsy, x=labelsYw+spacerY*.5+marginY, y=cogridy3, just=just, rot=gt$grid.labels.rot[2], gp=gpar(col=gt$grid.labels.col, cex=gt$grid.labels.size*scale, fontface=gt$fontface, fontfamily=gt$fontfamily))
@@ -493,7 +496,7 @@ get_gridline_labels <- function(lco, xax=NA, yax=NA) {
 
 		coor <- st_coordinates(gints)[,d]
 
-		ids2 <- unlist(mapply(rep, 1:length(wgint), gnrs, SIMPLIFY = FALSE))
+		ids2 <- unlist(mapply(rep, 1:length(wgint), gnrs, SIMPLIFY = FALSE), use.names = FALSE)
 		j <- 1L
 		for (i in which(gint)) {
 			cogrid[[i]] <- unname(coor[ids2 == j])
@@ -501,8 +504,8 @@ get_gridline_labels <- function(lco, xax=NA, yax=NA) {
 			j <- j + 1L
 		}
 		
-		cogrid <- unlist(cogrid)
-		ids <- unlist(ids)
+		cogrid <- unlist(cogrid, use.names = FALSE)
+		ids <- unlist(ids, use.names = FALSE)
 	}
 	list(cogrid = cogrid, ids = ids)
 }
@@ -705,7 +708,7 @@ polylineGrob2sfLines <- function(gL) {
 		coords <- cbind(gLi$x, gLi$y)
 		
 		if (length(gLi$id.lengths) > 1) {
-			ids <- unlist(mapply(rep, 1:length(gLi$id.lengths), gLi$id.lengths))
+			ids <- unlist(mapply(rep, 1:length(gLi$id.lengths), gLi$id.lengths), use.names = FALSE)
 			coords <- mapply(cbind, split(as.numeric(gLi$x), ids), split(as.numeric(gLi$y), ids))
 			st_multilinestring(coords)
 		} else {
