@@ -1,5 +1,10 @@
 check_raster_specials <- function(x, g, gt, shpcols, data, nx) {
 	## check raster shortcuts
+	# if (isTRUE(attr(data, "is.RGB"))) {
+	# 	is.colors <- TRUE
+	# 	nx <- 1
+	# 	x <- setdiff(names(data), c("tmapfilter", "GROUP_BY", "ALONG"))
+	# } else 
 	if ("PIXEL__COLOR" %in% names(data)) {
 		x <- "PIXEL__COLOR"
 		data$PIXEL__COLOR <- do.call("process_color", c(list(col=data$PIXEL__COLOR, alpha=g$alpha), gt$pc))
@@ -12,6 +17,11 @@ check_raster_specials <- function(x, g, gt, shpcols, data, nx) {
 	} else {
 		x <- g$col
 		
+		if (attr(data, "treat_as_by")) {
+			if (!is.na(x)) warning("col specification in tm_raster is ignored, since stars object contains a 3rd dimension, where its values are used to create facets", call. = FALSE)
+			x <- NA
+		}
+		
 		# by default, use the all data variables
 		if (is.na(x[1])) {
 			if (nlevels(data$GROUP_BY) > 1) {
